<?php

declare(encoding='UTF-8');

class Jolt_Dispatcher {
	
	private $controller = NULL;
	private $controllerPath = NULL;
	private $locator = NULL;
	private $renderedController = NULL;
	private $route = NULL;
	private $view = NULL;
	
	public function __construct() {
		
	}
	
	public function __destruct() {
		
	}
	
	public function attachLocator(Jolt_Controller_Locator $locator) {
		$this->locator = clone $locator;
		return $this;
	}
	
	public function attachRoute(Jolt_Route $route) {
		$this->route = clone $route;
		return $this;
	}
	
	public function attachView(Jolt_View $view) {
		$this->view = clone $view;
		return $this;
	}
	
	public function execute() {
		if ( !is_dir($this->controllerPath) ) {
			throw new Jolt_Exception('dispatcher_controller_path_does_not_exist');
		}
		
		if ( is_null($this->locator) ) {
			throw new Jolt_Exception('dispatcher_locator_is_null');
		}
		
		if ( is_null($this->route) ) {
			throw new Jolt_Exception('dispatcher_route_is_null');
		}
		
		if ( is_null($this->view) ) {
			throw new Jolt_Exception('dispatcher_view_is_null');
		}
		
		try {
			
			$controller = $this->locator->load($this->controllerPath, $this->route->getController());
			$controller->attachView($this->view);
			$controller->setAction($this->route->getAction());
			$controller->execute($this->route->getArgv());
			
			$this->controller = $controller;
			
		} catch ( Jolt_Exception $e ) {
			throw new Jolt_Exception("dispatcher_controller_missing: {$e->getMessage()}");
		}
		
		return true;
	}
	
	public function setControllerPath($controllerPath) {
		if ( empty($controllerPath) ) {
			throw new Jolt_Exception('dispatcher_controller_path_empty');
		}
		
		$pathLength = strlen($controllerPath);
		if ( $controllerPath[$pathLength-1] != DIRECTORY_SEPARATOR ) {
			$controllerPath .= DIRECTORY_SEPARATOR;
		}
		
		$this->controllerPath = $controllerPath;
		return $this;
	}
	
	public function getControllerPath() {
		return $this->controllerPath;
	}
	
	public function getController() {
		return $this->controller;
	}
	
}