# Welcome to Jolt - Energize Your Application

Jolt is a new PHP5.3+ framework aimed at fast and efficient web app development. Originally named Artisan System, Jolt was renamed to be more concise and easier to speak. Many of the ideas of Artisan System will be used in Jolt, but a lot of new ideas will be implemented as well.

For people 'stuck' with hosts running PHP < 5.3, this Jolt pre 5.3 offers a backwards compatible solution. However, it is advised to upgrade to PHP 5.3.

Jolt is built for handling routes, views, and controllers efficiently. In other words, Routes, Routing, Views, Controllers, and Layouts is what Jolt does very well. Models are decoupled from Jolt for several reasons, the biggest being that if you build an application on Jolt and decide to change later, you can move the display logic much easier than the business logic (which should be in your Models anyway: remember, fat models, skinny controllers). Jolt is built for speed, both in development time and server response time. A good framework provides a foundation for building your application and doesn't get in the way.

Jolt is hosted at [Joltcore.org](http://joltcore.org). Jolt bugs can be found at [http://bugs.joltcore.org](http://bugs.joltcore.org).

## Modified by
* Patrick van Kouteren <patrick@vankouteren.eu>

## A Sample Jolt Application
    <?php
    
    declare(encoding='UTF-8');
	
	require_once 'Jolt.php';

    try {
    
      $jolt = new Jolt;

      // Configuration
      $cfg = new Jolt_Configuration;
      $cfg->controllerPath = 'private/controllers/';
      $cfg->cssPath = 'public/css/';
      $cfg->jsPath = 'public/js/';
      $cfg->imagePath = 'public/images/';
      $cfg->routeParameter = '__u';
      $cfg->secureUrl = 'https://joltwebsite.com';
      $cfg->url = 'http://joltwebsite.com';
      $cfg->useRewrite = true;
      $cfg->viewPath = 'private/views/';

      // Configure the routes and router, of course, this could be pushed to another file
      $router = new Jolt_Router;
      $router->setParameters($_GET)
        ->setRequestMethod($_SERVER['REQUEST_METHOD'])
        ->setHttp404Route(new Jolt_Route_Named_Get('/', 'JoltApp_NotFound', 'error404'));

      // GET routes
      $router->addRoute(new Jolt_Route_Named_Get('/', 'JoltApp_Index', 'indexAction'))
        ->addRoute(new Jolt_Route_Named_Get('/index', 'JoltApp_Index', 'indexAction'))
        ->addRoute(new Jolt_Route_Named_Get('/register', 'JoltApp_Index', 'registerAction'))
        ->addRoute(new Jolt_Route_Named_Get('/logout', 'JoltApp_Index', 'logoutAction'))
        ->addRoute(new Jolt_Route_Named_Get('/dashboard', 'JoltApp_Dashboard', 'indexAction'));

      // POST routes
      $router->addRoute(new Jolt_Route_Named_Post('/login', 'JoltApp_Index', 'loginAction'))
        ->addRoute(new Jolt_Route_Named_Post('/register', 'JoltApp_Index', 'registerAccountAction'));

      $jolt->attachClient(new Jolt_Client)
        ->attachConfiguration($cfg)
        ->attachControllerLocator(new Jolt_Locator)
        ->attachDispatcher(new Jolt_Dispatcher)
        ->attachRouter($router)
        ->attachView(new Jolt_View);
  
      echo $jolt->execute();

    } catch ( Jolt_Exception $e ) {
      echo '<pre>', $e, '</pre>';
      exit;
    }